@@ -3,25 +3,14 @@
 
 import pytest
 
+from pytorch_tabular import TabularModel
 from pytorch_tabular.config import DataConfig, OptimizerConfig, TrainerConfig
 from pytorch_tabular.models import AutoIntConfig
-from pytorch_tabular import TabularModel
-from pytorch_tabular.categorical_encoders import CategoricalEmbeddingTransformer
 
 
 @pytest.mark.parametrize("multi_target", [True, False])
 @pytest.mark.parametrize(
-    "continuous_cols",
-    [
-        [
-            "AveRooms",
-            "AveBedrms",
-            "Population",
-            "AveOccup",
-            "Latitude",
-            "Longitude",
-        ],
-    ],
+    "continuous_cols", [["AveRooms", "AveBedrms", "Population", "AveOccup", "Latitude", "Longitude"]]
 )
 @pytest.mark.parametrize("categorical_cols", [["HouseAgeBin"]])
 @pytest.mark.parametrize("continuous_feature_transform", [None])
@@ -40,7 +29,7 @@ def test_regression(
     target_range,
     deep_layers,
     batch_norm_continuous_input,
-    attention_pooling
+    attention_pooling,
 ):
     (train, test, target) = regression_data
     if len(continuous_cols) + len(categorical_cols) == 0:
@@ -59,8 +48,8 @@ def test_regression(
             for target in data_config.target:
                 _target_range.append(
                     (
-                        train[target].min().item(),
-                        train[target].max().item(),
+                        float(train[target].min()),
+                        float(train[target].max()),
                     )
                 )
             model_config_params["target_range"] = _target_range
@@ -69,7 +58,11 @@ def test_regression(
         model_config_params["attention_pooling"] = attention_pooling
         model_config = AutoIntConfig(**model_config_params)
         trainer_config = TrainerConfig(
-            max_epochs=3, checkpoints=None, early_stopping=None, gpus=None, fast_dev_run=True
+            max_epochs=3,
+            checkpoints=None,
+            early_stopping=None,
+            accelerator="cpu",
+            fast_dev_run=True,
         )
         optimizer_config = OptimizerConfig()
 
@@ -106,7 +99,7 @@ def test_classification(
     continuous_feature_transform,
     normalize_continuous_features,
     deep_layers,
-    batch_norm_continuous_input
+    batch_norm_continuous_input,
 ):
     (train, test, target) = classification_data
     if len(continuous_cols) + len(categorical_cols) == 0:
@@ -124,7 +117,11 @@ def test_classification(
         model_config_params["batch_norm_continuous_input"] = batch_norm_continuous_input
         model_config = AutoIntConfig(**model_config_params)
         trainer_config = TrainerConfig(
-            max_epochs=3, checkpoints=None, early_stopping=None, gpus=None, fast_dev_run=True
+            max_epochs=3,
+            checkpoints=None,
+            early_stopping=None,
+            accelerator="cpu",
+            fast_dev_run=True,
         )
         optimizer_config = OptimizerConfig()
 
@@ -142,52 +139,71 @@ def test_classification(
         pred_df = tabular_model.predict(test)
         assert pred_df.shape[0] == test.shape[0]
 
-# import numpy as np
-# import pandas as pd
-# from sklearn.datasets import fetch_california_housing, fetch_covtype
 
-
-# def regression_data():
-#     dataset = fetch_california_housing(data_home="data", as_frame=True)
-#     df = dataset.frame.sample(5000)
-#     df["HouseAgeBin"] = pd.qcut(df["HouseAge"], q=4)
-#     df["HouseAgeBin"] = "age_" + df.HouseAgeBin.cat.codes.astype(str)
-#     test_idx = df.sample(int(0.2 * len(df)), random_state=42).index
-#     test = df[df.index.isin(test_idx)]
-#     train = df[~df.index.isin(test_idx)]
-#     return (train, test, dataset.target_names)
-
-
-# def classification_data():
-#     dataset = fetch_covtype(data_home="data")
-#     data = np.hstack([dataset.data, dataset.target.reshape(-1, 1)])[:10000, :]
-#     col_names = [f"feature_{i}" for i in range(data.shape[-1])]
-#     col_names[-1] = "target"
-#     data = pd.DataFrame(data, columns=col_names)
-#     data["feature_0_cat"] = pd.qcut(data["feature_0"], q=4)
-#     data["feature_0_cat"] = "feature_0_" + data.feature_0_cat.cat.codes.astype(str)
-#     test_idx = data.sample(int(0.2 * len(data)), random_state=42).index
-#     test = data[data.index.isin(test_idx)]
-#     train = data[~data.index.isin(test_idx)]
-#     return (train, test, ["target"])
-
-
-# test_regression(
-#     regression_data(),
-#     multi_target=True,
-#     continuous_cols=[
-#         "AveRooms",
-#         "AveBedrms",
-#         "Population",
-#         "AveOccup",
-#         "Latitude",
-#         "Longitude",
+# @pytest.mark.parametrize(
+#     "continuous_cols",
+#     [
+#         [
+#             "AveRooms",
+#             "AveBedrms",
+#             "Population",
+#             "AveOccup",
+#             "Latitude",
+#             "Longitude",
+#         ],
 #     ],
-#     categorical_cols=[],
-#     continuous_feature_transform="yeo-johnson",
-#     normalize_continuous_features=False,
-#     target_range=True,
 # )
-# test_embedding_transformer(regression_data())
+# @pytest.mark.parametrize("categorical_cols", [["HouseAgeBin"]])
+# @pytest.mark.parametrize("continuous_feature_transform", [None])
+# @pytest.mark.parametrize("normalize_continuous_features", [True])
+# @pytest.mark.parametrize("deep_layers", [True])
+# @pytest.mark.parametrize("batch_norm_continuous_input", [True])
+# @pytest.mark.parametrize("attention_pooling", [True])
+# @pytest.mark.parametrize("ssl_task", ["Denoising", "Contrastive"])
+# @pytest.mark.parametrize("aug_task", ["cutmix", "mixup"])
+# def test_ssl(
+#     regression_data,
+#     continuous_cols,
+#     categorical_cols,
+#     continuous_feature_transform,
+#     normalize_continuous_features,
+#     deep_layers,
+#     batch_norm_continuous_input,
+#     attention_pooling,
+#     ssl_task,
+#     aug_task,
+# ):
+#     (train, test, target) = regression_data
+#     if len(continuous_cols) + len(categorical_cols) == 0:
+#         assert True
+#     else:
+#         data_config = DataConfig(
+#             target=target,
+#             continuous_cols=continuous_cols,
+#             categorical_cols=categorical_cols,
+#             continuous_feature_transform=continuous_feature_transform,
+#             normalize_continuous_features=normalize_continuous_features,
+#         )
+#         model_config_params = dict(task="ssl", ssl_task=ssl_task, aug_task=aug_task)
+#         model_config_params["deep_layers"] = deep_layers
+#         model_config_params["batch_norm_continuous_input"] = batch_norm_continuous_input
+#         model_config_params["attention_pooling"] = attention_pooling
+#         model_config = AutoIntConfig(**model_config_params)
+#         trainer_config = TrainerConfig(
+#             max_epochs=3,
+#             checkpoints=None,
+#             early_stopping=None,
+#             fast_dev_run=True,
+#         )
+#         optimizer_config = OptimizerConfig()
 
-# classification_data()
+#         tabular_model = TabularModel(
+#             data_config=data_config,
+#             model_config=model_config,
+#             optimizer_config=optimizer_config,
+#             trainer_config=trainer_config,
+#         )
+#         tabular_model.fit(train=train, test=test)
+
+#         result = tabular_model.evaluate(test)
+#         assert "test_mean_squared_error" in result[0].keys()
